@@ -3,12 +3,15 @@
 #' @description
 #' `deployments()` gets the deployments from a Camera Trap Data Package object.
 #'
-#' `deployments<-()` is the assignment equivalent.
-#'   It should only be used within other functions, where the expected data
-#'   structure can be guaranteed.
+#' `deployments()<-` is the assignment equivalent.
+#'
+#' - It should only be used within other functions, where the expected data
+#' structure can be guaranteed.
+#' - Metadata (`x$spatial` and `x$temporal`) are updated to match the assigned
+#' deployments.
 #'
 #' @inheritParams print.camtrapdp
-#' @return [tibble::tibble()] data frame with deployments.
+#' @return A [tibble::tibble()] data frame with deployments.
 #' @family accessor functions
 #' @export
 #' @examples
@@ -33,6 +36,14 @@ deployments <- function(x) {
       class = "camtrapdp_error_assignment_wrong_class"
     )
   }
+
   purrr::pluck(x, "data", "deployments") <- dplyr::as_tibble(value)
+
+  # Update spatial and temporal scope in metadata
+  x <-
+    x %>%
+    update_spatial() %>%
+    update_temporal()
+
   return(x)
 }
