@@ -1,4 +1,5 @@
 test_that("print() returns output invisibly", {
+  skip_if_offline()
   # No output
   expect_output(output <- withVisible(print(example_dataset())))
   # Returned object does not auto print
@@ -6,6 +7,7 @@ test_that("print() returns output invisibly", {
 })
 
 test_that("print() informs about the number of tables, their rows and unclass()", {
+  skip_if_offline()
   x_no_additional <-
     example_dataset() %>%
     frictionless::remove_resource("individuals")
@@ -14,7 +16,7 @@ test_that("print() informs about the number of tables, their rows and unclass()"
   expect_output(
     print(x_no_additional),
     regexp = paste(
-      "A Camera Trap Data Package with 3 tables:",
+      "A Camera Trap Data Package \"camtrap-dp-example-dataset\" with 3 tables:",
       "* deployments: 4 rows",
       "* media: 423 rows",
       "* observations: 549 rows",
@@ -25,7 +27,12 @@ test_that("print() informs about the number of tables, their rows and unclass()"
   )
 
   # Extra table added
-  x_no_additional$data$extra <- data.frame("col_1" = c(1, 2), "col_2" = c("a", "b"))
+  x_no_additional$data$extra <-
+    data.frame(
+      "col_1" = c(1, 2),
+      "col_2" = c("a", "b"),
+      stringsAsFactors = FALSE
+    )
   expect_output(
     print(x_no_additional),
     regexp = "* extra: 2 rows",
@@ -34,6 +41,7 @@ test_that("print() informs about the number of tables, their rows and unclass()"
 })
 
 test_that("print() informs about additional resources", {
+  skip_if_offline()
   expect_output(
     print(example_dataset()),
     regexp = paste(
