@@ -13,12 +13,13 @@ test_that("write_dwc() writes CSV and meta.xml files to a directory and
   expect_identical(names(result), c("occurrence", "multimedia"))
   expect_s3_class(result$occurrence, "tbl")
   expect_s3_class(result$multimedia, "tbl")
+  expect_invisible(suppressMessages(write_dwc(x, temp_dir)))
 })
 
 test_that("write_dwc() returns the expected Darwin Core terms as columns", {
   skip_if_offline()
   x <- example_dataset()
-  temp_dir <- file.path(tempdir(), "dwc")
+  temp_dir <- tempdir()
   on.exit(unlink(temp_dir, recursive = TRUE))
   result <- suppressMessages(write_dwc(x, temp_dir))
 
@@ -61,6 +62,7 @@ test_that("write_dwc() returns the expected Darwin Core terms as columns", {
       "coordinatePrecision",
       "identifiedBy",
       "dateIdentified",
+      "identificationVerificationStatus",
       "identificationRemarks",
       "taxonID",
       "scientificName",
@@ -89,7 +91,7 @@ test_that("write_dwc() returns the expected Darwin Core mapping for the example
            dataset", {
   skip_if_offline()
   x <- example_dataset()
-  temp_dir <- file.path(tempdir(), "dwc")
+  temp_dir <- tempdir()
   on.exit(unlink(temp_dir, recursive = TRUE))
   suppressMessages(write_dwc(x, temp_dir))
 
@@ -98,10 +100,33 @@ test_that("write_dwc() returns the expected Darwin Core mapping for the example
   expect_snapshot_file(file.path(temp_dir, "meta.xml"))
 })
 
+test_that("write_dwc() can write media-based occurrences", {
+  skip_if_offline()
+  x <- example_dataset()
+  x$gbifIngestion$observationLevel <- "media"
+  temp_dir <- tempdir()
+  on.exit(unlink(temp_dir, recursive = TRUE))
+  result <- suppressMessages(write_dwc(x, temp_dir))
+  file.rename(
+    file.path(temp_dir, "occurrence.csv"),
+    file.path(temp_dir, "occurrence_media_based.csv")
+  )
+  file.rename(
+    file.path(temp_dir, "multimedia.csv"),
+    file.path(temp_dir, "multimedia_media_based.csv")
+  )
+
+  expect_snapshot_file(file.path(temp_dir, "occurrence_media_based.csv"))
+  expect_snapshot_file(file.path(temp_dir, "multimedia_media_based.csv"))
+  # Expect as many occurrences as media
+  expect_identical(nrow(result$occurrence), nrow(result$multimedia))
+  expect_in("07840dcc_1", result$occurrence$occurrenceID)
+})
+
 test_that("write_dwc() returns files that comply with the info in meta.xml", {
   skip_if_offline()
   x <- example_dataset()
-  temp_dir <- file.path(tempdir(), "dwc")
+  temp_dir <- tempdir()
   on.exit(unlink(temp_dir, recursive = TRUE))
   suppressMessages(write_dwc(x, temp_dir))
 
@@ -109,3 +134,15 @@ test_that("write_dwc() returns files that comply with the info in meta.xml", {
   expect_meta_match(file.path(temp_dir, "occurrence.csv"))
   expect_meta_match(file.path(temp_dir, "multimedia.csv"))
 })
+
+test_that("write_dwc() returns output when taxonID is missing", {
+  skip_if_offline()
+  x <- example_dataset()
+  optional_cols <- c("taxon.taxonID")
+  observations(x) <-
+    dplyr::select(observations(x), -dplyr::all_of(optional_cols))
+  temp_dir <- tempdir()
+  on.exit(unlink(temp_dir, recursive = TRUE))
+
+  expect_no_error(suppressMessages(write_dwc(x, temp_dir)))
+})
